@@ -30,7 +30,7 @@ use Config ();
 
 use constant HAS_SETLOCALE => $Config::Config{d_setlocale};
 
-our $VERSION = '3.000';
+our $VERSION = '3.001';
 our $FORMAT  = '%H:%M:%S %d-%b-%Y';    # default strftime() format
 our @LOCALE_SUFFIX = qw( .ISO8859-1 .ISO_8859-15 .US-ASCII .UTF-8 );
 
@@ -178,7 +178,7 @@ sub throw {
 
 package Template::Plugin::Date::Calc;
 use base qw( Template::Plugin );
-use vars qw( $AUTOLOAD );
+our $AUTOLOAD;
 *throw = \&Template::Plugin::Date::throw;
 
 sub AUTOLOAD {
@@ -197,7 +197,7 @@ sub AUTOLOAD {
 
 package Template::Plugin::Date::Manip;
 use base qw( Template::Plugin );
-use vars qw( $AUTOLOAD );
+our $AUTOLOAD;
 *throw = \&Template::Plugin::Date::throw;
 
 sub AUTOLOAD {
